@@ -31,6 +31,9 @@ pub struct Opts {
     #[clap(long, default_value = "25565")]
     pub port: u16,
 
+    #[clap(long, default_value = "8080")]
+    pub ws_port: u16,
+
     #[clap(short, long, default_value = "500")]
     pub delay: u64,
 
