@@ -33,7 +33,7 @@ use crate::protocol::encrypt::{rand_bits, Rsa};
 use crate::protocol::io::reader::PacketReader;
 use crate::protocol::io::writer::{PacketWriteChannel, PacketWriter};
 use crate::protocol::v340::clientbound::{JoinGame, LoginSuccess};
-use crate::protocol::v340::serverbound::{ClientStatusAction, DigStatus, Hand, HandshakeNextState};
+use crate::protocol::v340::serverbound::{ClientStatusAction, DigStatus, Hand, HandshakeNextState, InteractEntityKind};
 use crate::storage::block::{BlockLocation, BlockState};
 use crate::storage::blocks::ChunkLocation;
 use crate::storage::entities::EntityKind;
@@ -199,6 +199,22 @@ impl EventQueue340 {
                 let PlayDisconnect { reason } = data.read();
                 processor.on_disconnect(&reason);
             }
+            PlayerListItem::ID => {
+                let PlayerListItem { players } = data.read();
+                for Player { uuid, list_type } in players {
+                    match list_type {
+                        PlayerListType::AddPlayer(add) => {
+                            processor.on_player_join(uuid.0, add.name);
+                        }
+                        PlayerListType::UpdateGamemode(_) => {}
+                        PlayerListType::UpdateLatency(_) => {}
+                        PlayerListType::UpdateDisplayName(_) => {}
+                        PlayerListType::RemovePlayer => {
+                            processor.on_player_leave(uuid.0)
+                        }
+                    }
+                }
+            }
             // ignore
             ChatMessage::ID => {
                 let ChatMessage { chat, position: _ } = data.read();
@@ -261,6 +277,13 @@ impl InterfaceOut for Interface340 {
         });
     }
 
+    fn attack_entity(&mut self, id: u32) {
+        self.write(serverbound::InteractEntity {
+            id: id.into(),
+            kind: InteractEntityKind::Attack,
+        })
+    }
+
     fn send_chat(&mut self, message: &str) {
         self.write(serverbound::ChatMessage {
             message: message.to_string()
